==> XLConnect_0.1-9.tar.gz: XLConnect/R/workbook.mergeCells.R <==
#############################################################################
#
# XLConnect
# Copyright (C) 2010-2012 Mirai Solutions GmbH
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#############################################################################

#############################################################################
#
# Merging cells in a worksheet
# 
# Author: Martin Studer, Mirai Solutions GmbH
#
#############################################################################

setGeneric("mergeCells",
		function(object, sheet, ...) standardGeneric("mergeCells"))

setMethod("mergeCells", 
		signature(object = "workbook", sheet = "numeric"), 
		function(object, sheet, reference) {
			xlcCall(object, "mergeCells", as.integer(sheet - 1), reference)
			invisible()
		}
)

setMethod("mergeCells", 
		signature(object = "workbook", sheet = "character"), 
		function(object, sheet, reference) {
			xlcCall(object, "mergeCells", sheet, reference)
			invisible()
		}
)

==> XLConnect_0.2-1.tar.gz: XLConnect/R/workbook.mergeCells.R <==
#############################################################################
#
# XLConnect
# Copyright (C) 2010-2012 Mirai Solutions GmbH
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#############################################################################

#############################################################################
#
# Merging cells in a worksheet
# 
# Author: Martin Studer, Mirai Solutions GmbH
#
#############################################################################

setGeneric("mergeCells",
		function(object, sheet, reference) standardGeneric("mergeCells"))

setMethod("mergeCells", 
		signature(object = "workbook", sheet = "numeric"), 
		function(object, sheet, reference) {
			xlcCall(object, "mergeCells", as.integer(sheet - 1), reference)
			invisible()
		}
)

setMethod("mergeCells", 
		signature(object = "workbook", sheet = "character"), 
		function(object, sheet, reference) {
			xlcCall(object, "mergeCells", sheet, reference)
			invisible()
		}
)
